/*   -*- buffer-read-only: t -*- vi: set ro:
 *
 *  DO NOT EDIT THIS FILE   (tcprewrite_opts.c)
 *
 *  It has been AutoGen-ed
 *  From the definitions    ../../src/tcprewrite_opts.def
 *  and the template file   options
 *
 * Generated from AutoOpts 42:1:17 templates.
 *
 *  AutoOpts is a copyrighted work.  This source file is not encumbered
 *  by AutoOpts licensing, but is provided under the licensing terms chosen
 *  by the tcprewrite author or copyright holder.  AutoOpts is
 *  licensed under the terms of the LGPL.  The redistributable library
 *  (``libopts'') is licensed under the terms of either the LGPL or, at the
 *  users discretion, the BSD license.  See the AutoOpts and/or libopts sources
 *  for details.
 *
 * The tcprewrite program is copyrighted and licensed
 * under the following terms:
 *
 *  Copyright (C) 2000-2022 Aaron Turner and Fred Klassen, all rights reserved.
 *  This is free software. It is licensed for use, modification and
 *  redistribution under the terms of the GNU General Public License,
 *  version 3 or later <http://gnu.org/licenses/gpl.html>
 *
 *  tcprewrite is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  tcprewrite is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *  See the GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __doxygen__
#define OPTION_CODE_COMPILE 1
#include "tcprewrite_opts.h"
#include <sys/types.h>
#include <sys/stat.h>

#include <errno.h>
#include <fcntl.h>
#include <limits.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#ifdef  __cplusplus
extern "C" {
#endif
extern FILE * option_usage_fp;
#define zCopyright      (tcprewrite_opt_strs+0)
#define zLicenseDescrip (tcprewrite_opt_strs+285)

/*
 *  global included definitions
 */
#include "defines.h"
#include "common.h"
#include "config.h"
#include "tcprewrite.h"
#include <stdlib.h>
#include <string.h>
extern tcprewrite_opt_t options;


#ifndef NULL
#  define NULL 0
#endif

/**
 *  static const strings for tcprewrite options
 */
static char const tcprewrite_opt_strs[4988] =
/*     0 */ "tcprewrite (tcprewrite)\n"
            "Copyright (C) 2000-2022 Aaron Turner and Fred Klassen, all rights reserved.\n"
            "This is free software. It is licensed for use, modification and\n"
            "redistribution under the terms of the GNU General Public License,\n"
            "version 3 or later <http://gnu.org/licenses/gpl.html>\n\0"
/*   285 */ "tcprewrite is free software: you can redistribute it and/or modify it under\n"
            "the terms of the GNU General Public License as published by the Free\n"
            "Software Foundation, either version 3 of the License, or (at your option)\n"
            "any later version.\n\n"
            "tcprewrite is distributed in the hope that it will be useful, but WITHOUT\n"
            "ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or\n"
            "FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for\n"
            "more details.\n\n"
            "You should have received a copy of the GNU General Public License along\n"
            "with this program.  If not, see <http://www.gnu.org/licenses/>.\n\0"
/*   894 */ ":\0"
/*   896 */ "Rewrite TCP/UDP ports\0"
/*   918 */ "PORTMAP\0"
/*   926 */ "portmap\0"
/*   934 */ "Randomize src/dst IPv4/v6 addresses w/ given seed\0"
/*   984 */ "SEED\0"
/*   989 */ "seed\0"
/*   994 */ "Rewrite IPv4/v6 addresses using pseudo-NAT\0"
/*  1037 */ "PNAT\0"
/*  1042 */ "pnat\0"
/*  1047 */ "Rewrite source IPv4/v6 addresses using pseudo-NAT\0"
/*  1097 */ "SRCIPMAP\0"
/*  1106 */ "srcipmap\0"
/*  1115 */ "Rewrite destination IPv4/v6 addresses using pseudo-NAT\0"
/*  1170 */ "DSTIPMAP\0"
/*  1179 */ "dstipmap\0"
/*  1188 */ "Rewrite IP addresses to be between two endpoints\0"
/*  1237 */ "ENDPOINTS\0"
/*  1247 */ "endpoints\0"
/*  1257 */ "Change TCP Sequence (and ACK) numbers /w given seed\0"
/*  1309 */ "TCP_SEQUENCE\0"
/*  1322 */ "tcp-sequence\0"
/*  1335 */ "Skip rewriting broadcast/multicast IPv4/v6 addresses\0"
/*  1388 */ "SKIPBROADCAST\0"
/*  1402 */ "skipbroadcast\0"
/*  1416 */ "Force recalculation of IPv4/TCP/UDP header checksums\0"
/*  1469 */ "FIXCSUM\0"
/*  1477 */ "fixcsum\0"
/*  1485 */ "Override default MTU length (1500 bytes)\0"
/*  1526 */ "MTU\0"
/*  1530 */ "mtu\0"
/*  1534 */ "Truncate packets larger then specified MTU\0"
/*  1577 */ "MTU_TRUNC\0"
/*  1587 */ "mtu-trunc\0"
/*  1597 */ "Remove Ethernet checksums (FCS) from end of frames\0"
/*  1648 */ "EFCS\0"
/*  1653 */ "efcs\0"
/*  1658 */ "Modify the IPv4/v6 TTL/Hop Limit\0"
/*  1691 */ "TTL\0"
/*  1695 */ "ttl\0"
/*  1699 */ "Set the IPv4 TOS/DiffServ/ECN byte\0"
/*  1734 */ "TOS\0"
/*  1738 */ "tos\0"
/*  1742 */ "Set the IPv6 Traffic Class byte\0"
/*  1774 */ "TCLASS\0"
/*  1781 */ "tclass\0"
/*  1788 */ "Set the IPv6 Flow Label\0"
/*  1812 */ "FLOWLABEL\0"
/*  1822 */ "flowlabel\0"
/*  1832 */ "Pad or truncate packet data to match header length\0"
/*  1883 */ "FIXLEN\0"
/*  1890 */ "fixlen\0"
/*  1897 */ "Fuzz 1 in X packets.  Edit bytes, length, or emulate packet drop\0"
/*  1962 */ "FUZZ_SEED\0"
/*  1972 */ "fuzz-seed\0"
/*  1982 */ "Set the Fuzz 1 in X packet ratio (default 1 in 8 packets)\0"
/*  2040 */ "FUZZ_FACTOR\0"
/*  2052 */ "fuzz-factor\0"
/*  2064 */ "Skip rewriting broadcast/multicast Layer 2 addresses\0"
/*  2117 */ "SKIPL2BROADCAST\0"
/*  2133 */ "skipl2broadcast\0"
/*  2149 */ "Override output DLT encapsulation\0"
/*  2183 */ "DLT\0"
/*  2187 */ "dlt\0"
/*  2191 */ "Override destination ethernet MAC addresses\0"
/*  2235 */ "ENET_DMAC\0"
/*  2245 */ "enet-dmac\0"
/*  2255 */ "Override source ethernet MAC addresses\0"
/*  2294 */ "ENET_SMAC\0"
/*  2304 */ "enet-smac\0"
/*  2314 */ "Substitute MAC addresses\0"
/*  2339 */ "ENET_SUBSMAC\0"
/*  2352 */ "enet-subsmac\0"
/*  2365 */ "Randomize MAC addresses\0"
/*  2389 */ "ENET_MAC_SEED\0"
/*  2403 */ "enet-mac-seed\0"
/*  2417 */ "ENET_MAC_SEED_KEEP_BYTES\0"
/*  2442 */ "enet-mac-seed-keep-bytes\0"
/*  2467 */ "Specify ethernet 802.1q VLAN tag mode\0"
/*  2505 */ "ENET_VLAN\0"
/*  2515 */ "enet-vlan\0"
/*  2525 */ "Specify the new ethernet 802.1q VLAN tag value\0"
/*  2572 */ "ENET_VLAN_TAG\0"
/*  2586 */ "enet-vlan-tag\0"
/*  2600 */ "Specify the ethernet 802.1q VLAN CFI value\0"
/*  2643 */ "ENET_VLAN_CFI\0"
/*  2657 */ "enet-vlan-cfi\0"
/*  2671 */ "Specify the ethernet 802.1q VLAN priority\0"
/*  2713 */ "ENET_VLAN_PRI\0"
/*  2727 */ "enet-vlan-pri\0"
/*  2741 */ "Specify VLAN tag protocol 802.1q or 802.1ad\0"
/*  2785 */ "ENET_VLAN_PROTO\0"
/*  2801 */ "enet-vlan-proto\0"
/*  2817 */ "Specify HDLC control value\0"
/*  2844 */ "HDLC_CONTROL\0"
/*  2857 */ "hdlc-control\0"
/*  2870 */ "Specify HDLC address\0"
/*  2891 */ "HDLC_ADDRESS\0"
/*  2904 */ "hdlc-address\0"
/*  2917 */ "Set output file DLT type\0"
/*  2942 */ "USER_DLT\0"
/*  2951 */ "user-dlt\0"
/*  2960 */ "Rewrite Data-Link layer with user specified data\0"
/*  3009 */ "USER_DLINK\0"
/*  3020 */ "user-dlink\0"
/*  3031 */ "Enable debugging output\0"
/*  3055 */ "DBUG\0"
/*  3060 */ "dbug\0"
/*  3065 */ "Input pcap file to be processed\0"
/*  3097 */ "INFILE\0"
/*  3104 */ "infile\0"
/*  3111 */ "Output pcap file\0"
/*  3128 */ "OUTFILE\0"
/*  3136 */ "outfile\0"
/*  3144 */ "Split traffic via tcpprep cache file\0"
/*  3181 */ "CACHEFILE\0"
/*  3191 */ "cachefile\0"
/*  3201 */ "Print decoded packets via tcpdump to STDOUT\0"
/*  3245 */ "VERBOSE\0"
/*  3253 */ "verbose\0"
/*  3261 */ "Arguments passed to tcpdump decoder\0"
/*  3297 */ "DECODE\0"
/*  3304 */ "decode\0"
/*  3311 */ "Parse fragroute configuration file\0"
/*  3346 */ "FRAGROUTE\0"
/*  3356 */ "fragroute\0"
/*  3366 */ "Which flows to apply fragroute to: c2s, s2c, both\0"
/*  3416 */ "FRAGDIR\0"
/*  3424 */ "fragdir\0"
/*  3432 */ "Skip writing packets with soft errors\0"
/*  3470 */ "SKIP_SOFT_ERRORS\0"
/*  3487 */ "skip-soft-errors\0"
/*  3504 */ "Print version information\0"
/*  3530 */ "VERSION\0"
/*  3538 */ "version\0"
/*  3546 */ "Display less usage information and exit\0"
/*  3586 */ "LESS_HELP\0"
/*  3596 */ "less-help\0"
/*  3606 */ "display extended usage information and exit\0"
/*  3650 */ "help\0"
/*  3655 */ "extended usage information passed thru pager\0"
/*  3700 */ "more-help\0"
/*  3710 */ "save the option state to a config file\0"
/*  3749 */ "save-opts\0"
/*  3759 */ "load options from a config file\0"
/*  3791 */ "LOAD_OPTS\0"
/*  3801 */ "no-load-opts\0"
/*  3814 */ "no\0"
/*  3817 */ "TCPREWRITE\0"
/*  3828 */ "tcprewrite (tcprewrite) - Rewrite the packets in a pcap file.\n"
            "Usage:  %s [ -<flag> [<val>] | --<name>[{=| }<val>] ]...\n\0"
/*  3948 */ "$$/\0"
/*  3952 */ ".tcprewriterc\0"
/*  3966 */ "tcpreplay-users@lists.sourceforge.net\0"
/*  4004 */ "Tcprewrite is a tool to rewrite packets stored in 'pcap(3)' file format,\n"
            "such as created by tools such as 'tcpdump(1)' and 'wireshark(1)'.  Once a\n"
            "pcap file has had it's packets rewritten, they can be replayed back out on\n"
            "the network using 'tcpreplay(1)'.\n\n"
            "tcprewrite currently supports reading the following DLT types:\n\n\n"
            "'DLT_C_HDLC' aka Cisco HDLC\n\n\n"
            "'DLT_EN10MB' aka Ethernet\n\n\n"
            "'DLT_LINUX_SLL' aka Linux Cooked Socket\n\n\n"
            "'DLT_RAW' aka RAW IP\n\n\n"
            "'DLT_NULL' aka BSD Loopback\n\n\n"
            "'DLT_LOOP' aka OpenBSD Loopback\n\n\n"
            "'DLT_IEEE802_11' aka 802.11a/b/g\n\n\n"
            "'DLT_IEEE802_11_RADIO' aka 802.11a/b/g with Radiotap headers\n\n\n"
            "'DLT_JUNIPER_ETHER' aka Juniper Encapsulated Ethernet\n\n\n"
            "'DLT_PPP_SERIAL' aka PPP over Serial\n\n"
            "Please see the --dlt option for supported DLT types for writing.\n\n"
            "The packet editing features of tcprewrite which distinguish between\n"
            "\"client\" and \"server\" traffic requires a tcpprep(1) cache file.\n\n"
            "For more details, please see the Tcpreplay Manual at:\n"
            "http://tcpreplay.appneta.com\n";

/**
 *  tcpedit option description:
 */
/** tcpedit option separation text */
#define TCPEDIT_DESC      (tcprewrite_opt_strs+894)
#define TCPEDIT_FLAGS     (OPTST_DOCUMENT | OPTST_NO_INIT)

/**
 *  portmap option description:
 */
/** Descriptive text for the portmap option */
#define PORTMAP_DESC      (tcprewrite_opt_strs+896)
/** Upper-cased name for the portmap option */
#define PORTMAP_NAME      (tcprewrite_opt_strs+918)
/** Name string for the portmap option */
#define PORTMAP_name      (tcprewrite_opt_strs+926)
/** Compiled in flag settings for the portmap option */
#define PORTMAP_FLAGS     (OPTST_DISABLED | OPTST_STACKED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  seed option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the seed option */
#define SEED_DESC      (tcprewrite_opt_strs+934)
/** Upper-cased name for the seed option */
#define SEED_NAME      (tcprewrite_opt_strs+984)
/** Name string for the seed option */
#define SEED_name      (tcprewrite_opt_strs+989)
/** Other options that appear in conjunction with the seed option */
static int const aSeedCantList[] = {
    INDEX_OPT_FUZZ_SEED, NO_EQUIVALENT };
/** Compiled in flag settings for the seed option */
#define SEED_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  pnat option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the pnat option */
#define PNAT_DESC      (tcprewrite_opt_strs+994)
/** Upper-cased name for the pnat option */
#define PNAT_NAME      (tcprewrite_opt_strs+1037)
/** Name string for the pnat option */
#define PNAT_name      (tcprewrite_opt_strs+1042)
/** Other options that appear in conjunction with the pnat option */
static int const aPnatCantList[] = {
    INDEX_OPT_SRCIPMAP, NO_EQUIVALENT };
/** Compiled in flag settings for the pnat option */
#define PNAT_FLAGS     (OPTST_DISABLED | OPTST_STACKED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  srcipmap option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the srcipmap option */
#define SRCIPMAP_DESC      (tcprewrite_opt_strs+1047)
/** Upper-cased name for the srcipmap option */
#define SRCIPMAP_NAME      (tcprewrite_opt_strs+1097)
/** Name string for the srcipmap option */
#define SRCIPMAP_name      (tcprewrite_opt_strs+1106)
/** Other options that appear in conjunction with the srcipmap option */
static int const aSrcipmapCantList[] = {
    INDEX_OPT_PNAT, NO_EQUIVALENT };
/** Compiled in flag settings for the srcipmap option */
#define SRCIPMAP_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  dstipmap option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the dstipmap option */
#define DSTIPMAP_DESC      (tcprewrite_opt_strs+1115)
/** Upper-cased name for the dstipmap option */
#define DSTIPMAP_NAME      (tcprewrite_opt_strs+1170)
/** Name string for the dstipmap option */
#define DSTIPMAP_name      (tcprewrite_opt_strs+1179)
/** Other options that appear in conjunction with the dstipmap option */
static int const aDstipmapCantList[] = {
    INDEX_OPT_PNAT, NO_EQUIVALENT };
/** Compiled in flag settings for the dstipmap option */
#define DSTIPMAP_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  endpoints option description with
 *  "Must also have options" and "Incompatible options":
 */
#ifdef HAVE_CACHEFILE_SUPPORT
/** Descriptive text for the endpoints option */
#define ENDPOINTS_DESC      (tcprewrite_opt_strs+1188)
/** Upper-cased name for the endpoints option */
#define ENDPOINTS_NAME      (tcprewrite_opt_strs+1237)
/** Name string for the endpoints option */
#define ENDPOINTS_name      (tcprewrite_opt_strs+1247)
/** Other options that are required by the endpoints option */
static int const aEndpointsMustList[] = {
    INDEX_OPT_CACHEFILE, NO_EQUIVALENT };
/** Compiled in flag settings for the endpoints option */
#define ENDPOINTS_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

#else   /* disable endpoints */
#define ENDPOINTS_FLAGS     (OPTST_OMITTED | OPTST_NO_INIT)
#define aEndpointsMustList   NULL
#define ENDPOINTS_NAME      NULL
#define ENDPOINTS_DESC      NULL
#define ENDPOINTS_name      NULL
#endif  /* HAVE_CACHEFILE_SUPPORT */

/**
 *  tcp-sequence option description:
 */
/** Descriptive text for the tcp-sequence option */
#define TCP_SEQUENCE_DESC      (tcprewrite_opt_strs+1257)
/** Upper-cased name for the tcp-sequence option */
#define TCP_SEQUENCE_NAME      (tcprewrite_opt_strs+1309)
/** Name string for the tcp-sequence option */
#define TCP_SEQUENCE_name      (tcprewrite_opt_strs+1322)
/** The compiled in default value for the tcp-sequence option argument */
#define TCP_SEQUENCE_DFT_ARG   ((char const*)0)
/** Compiled in flag settings for the tcp-sequence option */
#define TCP_SEQUENCE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  skipbroadcast option description:
 */
/** Descriptive text for the skipbroadcast option */
#define SKIPBROADCAST_DESC      (tcprewrite_opt_strs+1335)
/** Upper-cased name for the skipbroadcast option */
#define SKIPBROADCAST_NAME      (tcprewrite_opt_strs+1388)
/** Name string for the skipbroadcast option */
#define SKIPBROADCAST_name      (tcprewrite_opt_strs+1402)
/** Compiled in flag settings for the skipbroadcast option */
#define SKIPBROADCAST_FLAGS     (OPTST_DISABLED)

/**
 *  fixcsum option description:
 */
/** Descriptive text for the fixcsum option */
#define FIXCSUM_DESC      (tcprewrite_opt_strs+1416)
/** Upper-cased name for the fixcsum option */
#define FIXCSUM_NAME      (tcprewrite_opt_strs+1469)
/** Name string for the fixcsum option */
#define FIXCSUM_name      (tcprewrite_opt_strs+1477)
/** Compiled in flag settings for the fixcsum option */
#define FIXCSUM_FLAGS     (OPTST_DISABLED)

/**
 *  mtu option description:
 */
/** Descriptive text for the mtu option */
#define MTU_DESC      (tcprewrite_opt_strs+1485)
/** Upper-cased name for the mtu option */
#define MTU_NAME      (tcprewrite_opt_strs+1526)
/** Name string for the mtu option */
#define MTU_name      (tcprewrite_opt_strs+1530)
/** Compiled in flag settings for the mtu option */
#define MTU_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  mtu-trunc option description:
 */
/** Descriptive text for the mtu-trunc option */
#define MTU_TRUNC_DESC      (tcprewrite_opt_strs+1534)
/** Upper-cased name for the mtu-trunc option */
#define MTU_TRUNC_NAME      (tcprewrite_opt_strs+1577)
/** Name string for the mtu-trunc option */
#define MTU_TRUNC_name      (tcprewrite_opt_strs+1587)
/** Compiled in flag settings for the mtu-trunc option */
#define MTU_TRUNC_FLAGS     (OPTST_DISABLED)

/**
 *  efcs option description:
 */
/** Descriptive text for the efcs option */
#define EFCS_DESC      (tcprewrite_opt_strs+1597)
/** Upper-cased name for the efcs option */
#define EFCS_NAME      (tcprewrite_opt_strs+1648)
/** Name string for the efcs option */
#define EFCS_name      (tcprewrite_opt_strs+1653)
/** Compiled in flag settings for the efcs option */
#define EFCS_FLAGS     (OPTST_DISABLED)

/**
 *  ttl option description:
 */
/** Descriptive text for the ttl option */
#define TTL_DESC      (tcprewrite_opt_strs+1658)
/** Upper-cased name for the ttl option */
#define TTL_NAME      (tcprewrite_opt_strs+1691)
/** Name string for the ttl option */
#define TTL_name      (tcprewrite_opt_strs+1695)
/** Compiled in flag settings for the ttl option */
#define TTL_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  tos option description:
 */
/** Descriptive text for the tos option */
#define TOS_DESC      (tcprewrite_opt_strs+1699)
/** Upper-cased name for the tos option */
#define TOS_NAME      (tcprewrite_opt_strs+1734)
/** Name string for the tos option */
#define TOS_name      (tcprewrite_opt_strs+1738)
/** Compiled in flag settings for the tos option */
#define TOS_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  tclass option description:
 */
/** Descriptive text for the tclass option */
#define TCLASS_DESC      (tcprewrite_opt_strs+1742)
/** Upper-cased name for the tclass option */
#define TCLASS_NAME      (tcprewrite_opt_strs+1774)
/** Name string for the tclass option */
#define TCLASS_name      (tcprewrite_opt_strs+1781)
/** Compiled in flag settings for the tclass option */
#define TCLASS_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  flowlabel option description:
 */
/** Descriptive text for the flowlabel option */
#define FLOWLABEL_DESC      (tcprewrite_opt_strs+1788)
/** Upper-cased name for the flowlabel option */
#define FLOWLABEL_NAME      (tcprewrite_opt_strs+1812)
/** Name string for the flowlabel option */
#define FLOWLABEL_name      (tcprewrite_opt_strs+1822)
/** Compiled in flag settings for the flowlabel option */
#define FLOWLABEL_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  fixlen option description:
 */
/** Descriptive text for the fixlen option */
#define FIXLEN_DESC      (tcprewrite_opt_strs+1832)
/** Upper-cased name for the fixlen option */
#define FIXLEN_NAME      (tcprewrite_opt_strs+1883)
/** Name string for the fixlen option */
#define FIXLEN_name      (tcprewrite_opt_strs+1890)
/** Compiled in flag settings for the fixlen option */
#define FIXLEN_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  fuzz-seed option description:
 */
/** Descriptive text for the fuzz-seed option */
#define FUZZ_SEED_DESC      (tcprewrite_opt_strs+1897)
/** Upper-cased name for the fuzz-seed option */
#define FUZZ_SEED_NAME      (tcprewrite_opt_strs+1962)
/** Name string for the fuzz-seed option */
#define FUZZ_SEED_name      (tcprewrite_opt_strs+1972)
/** The compiled in default value for the fuzz-seed option argument */
#define FUZZ_SEED_DFT_ARG   ((char const*)0)
/** Compiled in flag settings for the fuzz-seed option */
#define FUZZ_SEED_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  fuzz-factor option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the fuzz-factor option */
#define FUZZ_FACTOR_DESC      (tcprewrite_opt_strs+1982)
/** Upper-cased name for the fuzz-factor option */
#define FUZZ_FACTOR_NAME      (tcprewrite_opt_strs+2040)
/** Name string for the fuzz-factor option */
#define FUZZ_FACTOR_name      (tcprewrite_opt_strs+2052)
/** The compiled in default value for the fuzz-factor option argument */
#define FUZZ_FACTOR_DFT_ARG   ((char const*)8)
/** Other options that are required by the fuzz-factor option */
static int const aFuzz_FactorMustList[] = {
    INDEX_OPT_FUZZ_SEED, NO_EQUIVALENT };
/** Compiled in flag settings for the fuzz-factor option */
#define FUZZ_FACTOR_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  skipl2broadcast option description:
 */
/** Descriptive text for the skipl2broadcast option */
#define SKIPL2BROADCAST_DESC      (tcprewrite_opt_strs+2064)
/** Upper-cased name for the skipl2broadcast option */
#define SKIPL2BROADCAST_NAME      (tcprewrite_opt_strs+2117)
/** Name string for the skipl2broadcast option */
#define SKIPL2BROADCAST_name      (tcprewrite_opt_strs+2133)
/** Compiled in flag settings for the skipl2broadcast option */
#define SKIPL2BROADCAST_FLAGS     (OPTST_DISABLED)

/**
 *  dlt option description:
 */
/** Descriptive text for the dlt option */
#define DLT_DESC      (tcprewrite_opt_strs+2149)
/** Upper-cased name for the dlt option */
#define DLT_NAME      (tcprewrite_opt_strs+2183)
/** Name string for the dlt option */
#define DLT_name      (tcprewrite_opt_strs+2187)
/** Compiled in flag settings for the dlt option */
#define DLT_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  enet-dmac option description:
 */
/** Descriptive text for the enet-dmac option */
#define ENET_DMAC_DESC      (tcprewrite_opt_strs+2191)
/** Upper-cased name for the enet-dmac option */
#define ENET_DMAC_NAME      (tcprewrite_opt_strs+2235)
/** Name string for the enet-dmac option */
#define ENET_DMAC_name      (tcprewrite_opt_strs+2245)
/** Compiled in flag settings for the enet-dmac option */
#define ENET_DMAC_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  enet-smac option description:
 */
/** Descriptive text for the enet-smac option */
#define ENET_SMAC_DESC      (tcprewrite_opt_strs+2255)
/** Upper-cased name for the enet-smac option */
#define ENET_SMAC_NAME      (tcprewrite_opt_strs+2294)
/** Name string for the enet-smac option */
#define ENET_SMAC_name      (tcprewrite_opt_strs+2304)
/** Compiled in flag settings for the enet-smac option */
#define ENET_SMAC_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  enet-subsmac option description:
 */
/** Descriptive text for the enet-subsmac option */
#define ENET_SUBSMAC_DESC      (tcprewrite_opt_strs+2314)
/** Upper-cased name for the enet-subsmac option */
#define ENET_SUBSMAC_NAME      (tcprewrite_opt_strs+2339)
/** Name string for the enet-subsmac option */
#define ENET_SUBSMAC_name      (tcprewrite_opt_strs+2352)
/** Compiled in flag settings for the enet-subsmac option */
#define ENET_SUBSMAC_FLAGS     (OPTST_DISABLED | OPTST_STACKED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  enet-mac-seed option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the enet-mac-seed option */
#define ENET_MAC_SEED_DESC      (tcprewrite_opt_strs+2365)
/** Upper-cased name for the enet-mac-seed option */
#define ENET_MAC_SEED_NAME      (tcprewrite_opt_strs+2389)
/** Name string for the enet-mac-seed option */
#define ENET_MAC_SEED_name      (tcprewrite_opt_strs+2403)
/** Other options that appear in conjunction with the enet-mac-seed option */
static int const aEnet_Mac_SeedCantList[] = {
    INDEX_OPT_ENET_SMAC,
    INDEX_OPT_ENET_DMAC,
    INDEX_OPT_ENET_SUBSMAC, NO_EQUIVALENT };
/** Compiled in flag settings for the enet-mac-seed option */
#define ENET_MAC_SEED_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  enet-mac-seed-keep-bytes option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the enet-mac-seed-keep-bytes option */
#define ENET_MAC_SEED_KEEP_BYTES_DESC      (tcprewrite_opt_strs+2365)
/** Upper-cased name for the enet-mac-seed-keep-bytes option */
#define ENET_MAC_SEED_KEEP_BYTES_NAME      (tcprewrite_opt_strs+2417)
/** Name string for the enet-mac-seed-keep-bytes option */
#define ENET_MAC_SEED_KEEP_BYTES_name      (tcprewrite_opt_strs+2442)
/** Other options that are required by the enet-mac-seed-keep-bytes option */
static int const aEnet_Mac_Seed_Keep_BytesMustList[] = {
    INDEX_OPT_ENET_MAC_SEED, NO_EQUIVALENT };
/** Compiled in flag settings for the enet-mac-seed-keep-bytes option */
#define ENET_MAC_SEED_KEEP_BYTES_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  enet-vlan option description:
 */
/** Descriptive text for the enet-vlan option */
#define ENET_VLAN_DESC      (tcprewrite_opt_strs+2467)
/** Upper-cased name for the enet-vlan option */
#define ENET_VLAN_NAME      (tcprewrite_opt_strs+2505)
/** Name string for the enet-vlan option */
#define ENET_VLAN_name      (tcprewrite_opt_strs+2515)
/** Compiled in flag settings for the enet-vlan option */
#define ENET_VLAN_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  enet-vlan-tag option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the enet-vlan-tag option */
#define ENET_VLAN_TAG_DESC      (tcprewrite_opt_strs+2525)
/** Upper-cased name for the enet-vlan-tag option */
#define ENET_VLAN_TAG_NAME      (tcprewrite_opt_strs+2572)
/** Name string for the enet-vlan-tag option */
#define ENET_VLAN_TAG_name      (tcprewrite_opt_strs+2586)
/** Other options that are required by the enet-vlan-tag option */
static int const aEnet_Vlan_TagMustList[] = {
    INDEX_OPT_ENET_VLAN, NO_EQUIVALENT };
/** Compiled in flag settings for the enet-vlan-tag option */
#define ENET_VLAN_TAG_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  enet-vlan-cfi option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the enet-vlan-cfi option */
#define ENET_VLAN_CFI_DESC      (tcprewrite_opt_strs+2600)
/** Upper-cased name for the enet-vlan-cfi option */
#define ENET_VLAN_CFI_NAME      (tcprewrite_opt_strs+2643)
/** Name string for the enet-vlan-cfi option */
#define ENET_VLAN_CFI_name      (tcprewrite_opt_strs+2657)
/** Other options that are required by the enet-vlan-cfi option */
static int const aEnet_Vlan_CfiMustList[] = {
    INDEX_OPT_ENET_VLAN, NO_EQUIVALENT };
/** Compiled in flag settings for the enet-vlan-cfi option */
#define ENET_VLAN_CFI_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  enet-vlan-pri option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the enet-vlan-pri option */
#define ENET_VLAN_PRI_DESC      (tcprewrite_opt_strs+2671)
/** Upper-cased name for the enet-vlan-pri option */
#define ENET_VLAN_PRI_NAME      (tcprewrite_opt_strs+2713)
/** Name string for the enet-vlan-pri option */
#define ENET_VLAN_PRI_name      (tcprewrite_opt_strs+2727)
/** Other options that are required by the enet-vlan-pri option */
static int const aEnet_Vlan_PriMustList[] = {
    INDEX_OPT_ENET_VLAN, NO_EQUIVALENT };
/** Compiled in flag settings for the enet-vlan-pri option */
#define ENET_VLAN_PRI_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  enet-vlan-proto option description:
 */
/** Descriptive text for the enet-vlan-proto option */
#define ENET_VLAN_PROTO_DESC      (tcprewrite_opt_strs+2741)
/** Upper-cased name for the enet-vlan-proto option */
#define ENET_VLAN_PROTO_NAME      (tcprewrite_opt_strs+2785)
/** Name string for the enet-vlan-proto option */
#define ENET_VLAN_PROTO_name      (tcprewrite_opt_strs+2801)
/** Compiled in flag settings for the enet-vlan-proto option */
#define ENET_VLAN_PROTO_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  hdlc-control option description:
 */
/** Descriptive text for the hdlc-control option */
#define HDLC_CONTROL_DESC      (tcprewrite_opt_strs+2817)
/** Upper-cased name for the hdlc-control option */
#define HDLC_CONTROL_NAME      (tcprewrite_opt_strs+2844)
/** Name string for the hdlc-control option */
#define HDLC_CONTROL_name      (tcprewrite_opt_strs+2857)
/** Compiled in flag settings for the hdlc-control option */
#define HDLC_CONTROL_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  hdlc-address option description:
 */
/** Descriptive text for the hdlc-address option */
#define HDLC_ADDRESS_DESC      (tcprewrite_opt_strs+2870)
/** Upper-cased name for the hdlc-address option */
#define HDLC_ADDRESS_NAME      (tcprewrite_opt_strs+2891)
/** Name string for the hdlc-address option */
#define HDLC_ADDRESS_name      (tcprewrite_opt_strs+2904)
/** Compiled in flag settings for the hdlc-address option */
#define HDLC_ADDRESS_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  user-dlt option description:
 */
/** Descriptive text for the user-dlt option */
#define USER_DLT_DESC      (tcprewrite_opt_strs+2917)
/** Upper-cased name for the user-dlt option */
#define USER_DLT_NAME      (tcprewrite_opt_strs+2942)
/** Name string for the user-dlt option */
#define USER_DLT_name      (tcprewrite_opt_strs+2951)
/** Compiled in flag settings for the user-dlt option */
#define USER_DLT_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  user-dlink option description:
 */
/** Descriptive text for the user-dlink option */
#define USER_DLINK_DESC      (tcprewrite_opt_strs+2960)
/** Upper-cased name for the user-dlink option */
#define USER_DLINK_NAME      (tcprewrite_opt_strs+3009)
/** Name string for the user-dlink option */
#define USER_DLINK_name      (tcprewrite_opt_strs+3020)
/** Compiled in flag settings for the user-dlink option */
#define USER_DLINK_FLAGS     (OPTST_DISABLED | OPTST_STACKED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  dbug option description:
 */
#ifdef DEBUG
/** Descriptive text for the dbug option */
#define DBUG_DESC      (tcprewrite_opt_strs+3031)
/** Upper-cased name for the dbug option */
#define DBUG_NAME      (tcprewrite_opt_strs+3055)
/** Name string for the dbug option */
#define DBUG_name      (tcprewrite_opt_strs+3060)
/** The compiled in default value for the dbug option argument */
#define DBUG_DFT_ARG   ((char const*)0)
/** Compiled in flag settings for the dbug option */
#define DBUG_FLAGS     (OPTST_DISABLED | OPTST_IMM \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

#else   /* disable dbug */
#define DBUG_FLAGS     (OPTST_OMITTED | OPTST_NO_INIT)
#define DBUG_DFT_ARG   NULL
#define DBUG_NAME      NULL
#define DBUG_DESC      NULL
#define DBUG_name      NULL
#endif  /* DEBUG */

/**
 *  infile option description:
 */
/** Descriptive text for the infile option */
#define INFILE_DESC      (tcprewrite_opt_strs+3065)
/** Upper-cased name for the infile option */
#define INFILE_NAME      (tcprewrite_opt_strs+3097)
/** Name string for the infile option */
#define INFILE_name      (tcprewrite_opt_strs+3104)
/** Compiled in flag settings for the infile option */
#define INFILE_FLAGS     (OPTST_DISABLED | OPTST_MUST_SET | OPTST_IMM \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  outfile option description:
 */
/** Descriptive text for the outfile option */
#define OUTFILE_DESC      (tcprewrite_opt_strs+3111)
/** Upper-cased name for the outfile option */
#define OUTFILE_NAME      (tcprewrite_opt_strs+3128)
/** Name string for the outfile option */
#define OUTFILE_name      (tcprewrite_opt_strs+3136)
/** Compiled in flag settings for the outfile option */
#define OUTFILE_FLAGS     (OPTST_DISABLED | OPTST_MUST_SET \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  cachefile option description:
 */
/** Descriptive text for the cachefile option */
#define CACHEFILE_DESC      (tcprewrite_opt_strs+3144)
/** Upper-cased name for the cachefile option */
#define CACHEFILE_NAME      (tcprewrite_opt_strs+3181)
/** Name string for the cachefile option */
#define CACHEFILE_name      (tcprewrite_opt_strs+3191)
/** Compiled in flag settings for the cachefile option */
#define CACHEFILE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  verbose option description:
 */
#ifdef ENABLE_VERBOSE
/** Descriptive text for the verbose option */
#define VERBOSE_DESC      (tcprewrite_opt_strs+3201)
/** Upper-cased name for the verbose option */
#define VERBOSE_NAME      (tcprewrite_opt_strs+3245)
/** Name string for the verbose option */
#define VERBOSE_name      (tcprewrite_opt_strs+3253)
/** Compiled in flag settings for the verbose option */
#define VERBOSE_FLAGS     (OPTST_DISABLED | OPTST_IMM)

#else   /* disable verbose */
#define VERBOSE_FLAGS     (OPTST_OMITTED | OPTST_NO_INIT)
#define VERBOSE_NAME      NULL
#define VERBOSE_DESC      NULL
#define VERBOSE_name      NULL
#endif  /* ENABLE_VERBOSE */

/**
 *  decode option description with
 *  "Must also have options" and "Incompatible options":
 */
#ifdef ENABLE_VERBOSE
/** Descriptive text for the decode option */
#define DECODE_DESC      (tcprewrite_opt_strs+3261)
/** Upper-cased name for the decode option */
#define DECODE_NAME      (tcprewrite_opt_strs+3297)
/** Name string for the decode option */
#define DECODE_name      (tcprewrite_opt_strs+3304)
/** Other options that are required by the decode option */
static int const aDecodeMustList[] = {
    INDEX_OPT_VERBOSE, NO_EQUIVALENT };
/** Compiled in flag settings for the decode option */
#define DECODE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

#else   /* disable decode */
#define DECODE_FLAGS     (OPTST_OMITTED | OPTST_NO_INIT)
#define aDecodeMustList   NULL
#define DECODE_NAME      NULL
#define DECODE_DESC      NULL
#define DECODE_name      NULL
#endif  /* ENABLE_VERBOSE */

/**
 *  fragroute option description:
 */
#ifdef ENABLE_FRAGROUTE
/** Descriptive text for the fragroute option */
#define FRAGROUTE_DESC      (tcprewrite_opt_strs+3311)
/** Upper-cased name for the fragroute option */
#define FRAGROUTE_NAME      (tcprewrite_opt_strs+3346)
/** Name string for the fragroute option */
#define FRAGROUTE_name      (tcprewrite_opt_strs+3356)
/** Compiled in flag settings for the fragroute option */
#define FRAGROUTE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

#else   /* disable fragroute */
#define FRAGROUTE_FLAGS     (OPTST_OMITTED | OPTST_NO_INIT)
#define FRAGROUTE_NAME      NULL
#define FRAGROUTE_DESC      NULL
#define FRAGROUTE_name      NULL
#endif  /* ENABLE_FRAGROUTE */

/**
 *  fragdir option description with
 *  "Must also have options" and "Incompatible options":
 */
#ifdef ENABLE_FRAGROUTE
/** Descriptive text for the fragdir option */
#define FRAGDIR_DESC      (tcprewrite_opt_strs+3366)
/** Upper-cased name for the fragdir option */
#define FRAGDIR_NAME      (tcprewrite_opt_strs+3416)
/** Name string for the fragdir option */
#define FRAGDIR_name      (tcprewrite_opt_strs+3424)
/** Other options that are required by the fragdir option */
static int const aFragdirMustList[] = {
    INDEX_OPT_CACHEFILE, NO_EQUIVALENT };
/** Compiled in flag settings for the fragdir option */
#define FRAGDIR_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

#else   /* disable fragdir */
#define FRAGDIR_FLAGS     (OPTST_OMITTED | OPTST_NO_INIT)
#define aFragdirMustList   NULL
#define FRAGDIR_NAME      NULL
#define FRAGDIR_DESC      NULL
#define FRAGDIR_name      NULL
#endif  /* ENABLE_FRAGROUTE */

/**
 *  skip-soft-errors option description:
 */
/** Descriptive text for the skip-soft-errors option */
#define SKIP_SOFT_ERRORS_DESC      (tcprewrite_opt_strs+3432)
/** Upper-cased name for the skip-soft-errors option */
#define SKIP_SOFT_ERRORS_NAME      (tcprewrite_opt_strs+3470)
/** Name string for the skip-soft-errors option */
#define SKIP_SOFT_ERRORS_name      (tcprewrite_opt_strs+3487)
/** Compiled in flag settings for the skip-soft-errors option */
#define SKIP_SOFT_ERRORS_FLAGS     (OPTST_DISABLED)

/**
 *  version option description:
 */
/** Descriptive text for the version option */
#define VERSION_DESC      (tcprewrite_opt_strs+3504)
/** Upper-cased name for the version option */
#define VERSION_NAME      (tcprewrite_opt_strs+3530)
/** Name string for the version option */
#define VERSION_name      (tcprewrite_opt_strs+3538)
/** Compiled in flag settings for the version option */
#define VERSION_FLAGS     (OPTST_DISABLED)

/**
 *  less-help option description:
 */
/** Descriptive text for the less-help option */
#define LESS_HELP_DESC      (tcprewrite_opt_strs+3546)
/** Upper-cased name for the less-help option */
#define LESS_HELP_NAME      (tcprewrite_opt_strs+3586)
/** Name string for the less-help option */
#define LESS_HELP_name      (tcprewrite_opt_strs+3596)
/** Compiled in flag settings for the less-help option */
#define LESS_HELP_FLAGS     (OPTST_DISABLED | OPTST_IMM)

/*
 *  Help/More_Help option descriptions:
 */
#define HELP_DESC       (tcprewrite_opt_strs+3606)
#define HELP_name       (tcprewrite_opt_strs+3650)
#ifdef HAVE_WORKING_FORK
#define MORE_HELP_DESC  (tcprewrite_opt_strs+3655)
#define MORE_HELP_name  (tcprewrite_opt_strs+3700)
#define MORE_HELP_FLAGS (OPTST_IMM | OPTST_NO_INIT)
#else
#define MORE_HELP_DESC  HELP_DESC
#define MORE_HELP_name  HELP_name
#define MORE_HELP_FLAGS (OPTST_OMITTED | OPTST_NO_INIT)
#endif
#define SAVE_OPTS_DESC  (tcprewrite_opt_strs+3710)
#define SAVE_OPTS_name  (tcprewrite_opt_strs+3749)
#define LOAD_OPTS_DESC     (tcprewrite_opt_strs+3759)
#define LOAD_OPTS_NAME     (tcprewrite_opt_strs+3791)
#define NO_LOAD_OPTS_name  (tcprewrite_opt_strs+3801)
#define LOAD_OPTS_pfx      (tcprewrite_opt_strs+3814)
#define LOAD_OPTS_name     (NO_LOAD_OPTS_name + 3)
/**
 *  Declare option callback procedures
 */
#ifdef DEBUG
  static tOptProc doOptDbug;
#else /* not DEBUG */
# define doOptDbug NULL
#endif /* def/not DEBUG */
extern tOptProc
    optionBooleanVal,   optionNestedVal,    optionNumericVal,
    optionPagedUsage,   optionPrintVersion, optionResetOpt,
    optionStackArg,     optionTimeDate,     optionTimeVal,
    optionUnstackArg,   optionVendorOption;
static tOptProc
    doOptCachefile,                doOptEnet_Mac_Seed_Keep_Bytes,
    doOptEnet_Vlan_Cfi,            doOptEnet_Vlan_Pri,
    doOptEnet_Vlan_Tag,            doOptFlowlabel,
    doOptFuzz_Factor,              doOptFuzz_Seed,
    doOptLess_Help,                doOptMtu,
    doOptTclass,                   doOptTcp_Sequence,
    doOptTos,                      doOptVersion,
    doUsageOpt;

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 *  Define the tcprewrite Option Descriptions.
 * This is an array of OPTION_CT entries, one for each
 * option that the tcprewrite program responds to.
 */
static tOptDesc optDesc[OPTION_CT] = {
  {  /* entry idx, value */ 0, 0,
     /* equiv idx, value */ 0, 0,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 0, 0,
     /* opt state flags  */ TCPEDIT_FLAGS, 0,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ TCPEDIT_DESC, NULL, NULL,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 1, VALUE_OPT_PORTMAP,
     /* equiv idx, value */ 1, VALUE_OPT_PORTMAP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 9999, 0,
     /* opt state flags  */ PORTMAP_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --portmap */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionStackArg,
     /* desc, NAME, name */ PORTMAP_DESC, PORTMAP_NAME, PORTMAP_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 2, VALUE_OPT_SEED,
     /* equiv idx, value */ 2, VALUE_OPT_SEED,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ SEED_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --seed */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aSeedCantList,
     /* option proc      */ optionNumericVal,
     /* desc, NAME, name */ SEED_DESC, SEED_NAME, SEED_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 3, VALUE_OPT_PNAT,
     /* equiv idx, value */ 3, VALUE_OPT_PNAT,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 2, 0,
     /* opt state flags  */ PNAT_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --pnat */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aPnatCantList,
     /* option proc      */ optionStackArg,
     /* desc, NAME, name */ PNAT_DESC, PNAT_NAME, PNAT_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 4, VALUE_OPT_SRCIPMAP,
     /* equiv idx, value */ 4, VALUE_OPT_SRCIPMAP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ SRCIPMAP_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --srcipmap */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aSrcipmapCantList,
     /* option proc      */ NULL,
     /* desc, NAME, name */ SRCIPMAP_DESC, SRCIPMAP_NAME, SRCIPMAP_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 5, VALUE_OPT_DSTIPMAP,
     /* equiv idx, value */ 5, VALUE_OPT_DSTIPMAP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ DSTIPMAP_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --dstipmap */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aDstipmapCantList,
     /* option proc      */ NULL,
     /* desc, NAME, name */ DSTIPMAP_DESC, DSTIPMAP_NAME, DSTIPMAP_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 6, VALUE_OPT_ENDPOINTS,
     /* equiv idx, value */ 6, VALUE_OPT_ENDPOINTS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENDPOINTS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --endpoints */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aEndpointsMustList, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ ENDPOINTS_DESC, ENDPOINTS_NAME, ENDPOINTS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 7, VALUE_OPT_TCP_SEQUENCE,
     /* equiv idx, value */ 7, VALUE_OPT_TCP_SEQUENCE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ TCP_SEQUENCE_FLAGS, 0,
     /* last opt argumnt */ { TCP_SEQUENCE_DFT_ARG },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptTcp_Sequence,
     /* desc, NAME, name */ TCP_SEQUENCE_DESC, TCP_SEQUENCE_NAME, TCP_SEQUENCE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 8, VALUE_OPT_SKIPBROADCAST,
     /* equiv idx, value */ 8, VALUE_OPT_SKIPBROADCAST,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ SKIPBROADCAST_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --skipbroadcast */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ SKIPBROADCAST_DESC, SKIPBROADCAST_NAME, SKIPBROADCAST_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 9, VALUE_OPT_FIXCSUM,
     /* equiv idx, value */ 9, VALUE_OPT_FIXCSUM,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ FIXCSUM_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --fixcsum */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ FIXCSUM_DESC, FIXCSUM_NAME, FIXCSUM_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 10, VALUE_OPT_MTU,
     /* equiv idx, value */ 10, VALUE_OPT_MTU,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ MTU_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --mtu */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptMtu,
     /* desc, NAME, name */ MTU_DESC, MTU_NAME, MTU_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 11, VALUE_OPT_MTU_TRUNC,
     /* equiv idx, value */ 11, VALUE_OPT_MTU_TRUNC,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ MTU_TRUNC_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --mtu-trunc */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ MTU_TRUNC_DESC, MTU_TRUNC_NAME, MTU_TRUNC_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 12, VALUE_OPT_EFCS,
     /* equiv idx, value */ 12, VALUE_OPT_EFCS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ EFCS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --efcs */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ EFCS_DESC, EFCS_NAME, EFCS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 13, VALUE_OPT_TTL,
     /* equiv idx, value */ 13, VALUE_OPT_TTL,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ TTL_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --ttl */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ TTL_DESC, TTL_NAME, TTL_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 14, VALUE_OPT_TOS,
     /* equiv idx, value */ 14, VALUE_OPT_TOS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ TOS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --tos */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptTos,
     /* desc, NAME, name */ TOS_DESC, TOS_NAME, TOS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 15, VALUE_OPT_TCLASS,
     /* equiv idx, value */ 15, VALUE_OPT_TCLASS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ TCLASS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --tclass */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptTclass,
     /* desc, NAME, name */ TCLASS_DESC, TCLASS_NAME, TCLASS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 16, VALUE_OPT_FLOWLABEL,
     /* equiv idx, value */ 16, VALUE_OPT_FLOWLABEL,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ FLOWLABEL_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --flowlabel */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptFlowlabel,
     /* desc, NAME, name */ FLOWLABEL_DESC, FLOWLABEL_NAME, FLOWLABEL_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 17, VALUE_OPT_FIXLEN,
     /* equiv idx, value */ 17, VALUE_OPT_FIXLEN,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ FIXLEN_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --fixlen */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ FIXLEN_DESC, FIXLEN_NAME, FIXLEN_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 18, VALUE_OPT_FUZZ_SEED,
     /* equiv idx, value */ 18, VALUE_OPT_FUZZ_SEED,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ FUZZ_SEED_FLAGS, 0,
     /* last opt argumnt */ { FUZZ_SEED_DFT_ARG },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptFuzz_Seed,
     /* desc, NAME, name */ FUZZ_SEED_DESC, FUZZ_SEED_NAME, FUZZ_SEED_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 19, VALUE_OPT_FUZZ_FACTOR,
     /* equiv idx, value */ 19, VALUE_OPT_FUZZ_FACTOR,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ FUZZ_FACTOR_FLAGS, 0,
     /* last opt argumnt */ { FUZZ_FACTOR_DFT_ARG },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aFuzz_FactorMustList, NULL,
     /* option proc      */ doOptFuzz_Factor,
     /* desc, NAME, name */ FUZZ_FACTOR_DESC, FUZZ_FACTOR_NAME, FUZZ_FACTOR_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 20, VALUE_OPT_SKIPL2BROADCAST,
     /* equiv idx, value */ 20, VALUE_OPT_SKIPL2BROADCAST,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ SKIPL2BROADCAST_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --skipl2broadcast */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ SKIPL2BROADCAST_DESC, SKIPL2BROADCAST_NAME, SKIPL2BROADCAST_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 21, VALUE_OPT_DLT,
     /* equiv idx, value */ 21, VALUE_OPT_DLT,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ DLT_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --dlt */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ DLT_DESC, DLT_NAME, DLT_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 22, VALUE_OPT_ENET_DMAC,
     /* equiv idx, value */ 22, VALUE_OPT_ENET_DMAC,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_DMAC_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-dmac */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ ENET_DMAC_DESC, ENET_DMAC_NAME, ENET_DMAC_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 23, VALUE_OPT_ENET_SMAC,
     /* equiv idx, value */ 23, VALUE_OPT_ENET_SMAC,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_SMAC_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-smac */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ ENET_SMAC_DESC, ENET_SMAC_NAME, ENET_SMAC_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 24, VALUE_OPT_ENET_SUBSMAC,
     /* equiv idx, value */ 24, VALUE_OPT_ENET_SUBSMAC,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 9999, 0,
     /* opt state flags  */ ENET_SUBSMAC_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-subsmac */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionStackArg,
     /* desc, NAME, name */ ENET_SUBSMAC_DESC, ENET_SUBSMAC_NAME, ENET_SUBSMAC_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 25, VALUE_OPT_ENET_MAC_SEED,
     /* equiv idx, value */ 25, VALUE_OPT_ENET_MAC_SEED,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_MAC_SEED_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-mac-seed */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aEnet_Mac_SeedCantList,
     /* option proc      */ optionNumericVal,
     /* desc, NAME, name */ ENET_MAC_SEED_DESC, ENET_MAC_SEED_NAME, ENET_MAC_SEED_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 26, VALUE_OPT_ENET_MAC_SEED_KEEP_BYTES,
     /* equiv idx, value */ 26, VALUE_OPT_ENET_MAC_SEED_KEEP_BYTES,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_MAC_SEED_KEEP_BYTES_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-mac-seed-keep-bytes */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aEnet_Mac_Seed_Keep_BytesMustList, NULL,
     /* option proc      */ doOptEnet_Mac_Seed_Keep_Bytes,
     /* desc, NAME, name */ ENET_MAC_SEED_KEEP_BYTES_DESC, ENET_MAC_SEED_KEEP_BYTES_NAME, ENET_MAC_SEED_KEEP_BYTES_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 27, VALUE_OPT_ENET_VLAN,
     /* equiv idx, value */ 27, VALUE_OPT_ENET_VLAN,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_VLAN_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-vlan */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ ENET_VLAN_DESC, ENET_VLAN_NAME, ENET_VLAN_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 28, VALUE_OPT_ENET_VLAN_TAG,
     /* equiv idx, value */ 28, VALUE_OPT_ENET_VLAN_TAG,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_VLAN_TAG_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-vlan-tag */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aEnet_Vlan_TagMustList, NULL,
     /* option proc      */ doOptEnet_Vlan_Tag,
     /* desc, NAME, name */ ENET_VLAN_TAG_DESC, ENET_VLAN_TAG_NAME, ENET_VLAN_TAG_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 29, VALUE_OPT_ENET_VLAN_CFI,
     /* equiv idx, value */ 29, VALUE_OPT_ENET_VLAN_CFI,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_VLAN_CFI_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-vlan-cfi */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aEnet_Vlan_CfiMustList, NULL,
     /* option proc      */ doOptEnet_Vlan_Cfi,
     /* desc, NAME, name */ ENET_VLAN_CFI_DESC, ENET_VLAN_CFI_NAME, ENET_VLAN_CFI_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 30, VALUE_OPT_ENET_VLAN_PRI,
     /* equiv idx, value */ 30, VALUE_OPT_ENET_VLAN_PRI,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_VLAN_PRI_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-vlan-pri */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aEnet_Vlan_PriMustList, NULL,
     /* option proc      */ doOptEnet_Vlan_Pri,
     /* desc, NAME, name */ ENET_VLAN_PRI_DESC, ENET_VLAN_PRI_NAME, ENET_VLAN_PRI_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 31, VALUE_OPT_ENET_VLAN_PROTO,
     /* equiv idx, value */ 31, VALUE_OPT_ENET_VLAN_PROTO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ENET_VLAN_PROTO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --enet-vlan-proto */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ ENET_VLAN_PROTO_DESC, ENET_VLAN_PROTO_NAME, ENET_VLAN_PROTO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 32, VALUE_OPT_HDLC_CONTROL,
     /* equiv idx, value */ 32, VALUE_OPT_HDLC_CONTROL,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ HDLC_CONTROL_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --hdlc-control */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionNumericVal,
     /* desc, NAME, name */ HDLC_CONTROL_DESC, HDLC_CONTROL_NAME, HDLC_CONTROL_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 33, VALUE_OPT_HDLC_ADDRESS,
     /* equiv idx, value */ 33, VALUE_OPT_HDLC_ADDRESS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ HDLC_ADDRESS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --hdlc-address */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionNumericVal,
     /* desc, NAME, name */ HDLC_ADDRESS_DESC, HDLC_ADDRESS_NAME, HDLC_ADDRESS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 34, VALUE_OPT_USER_DLT,
     /* equiv idx, value */ 34, VALUE_OPT_USER_DLT,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ USER_DLT_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --user-dlt */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionNumericVal,
     /* desc, NAME, name */ USER_DLT_DESC, USER_DLT_NAME, USER_DLT_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 35, VALUE_OPT_USER_DLINK,
     /* equiv idx, value */ 35, VALUE_OPT_USER_DLINK,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 2, 0,
     /* opt state flags  */ USER_DLINK_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --user-dlink */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionStackArg,
     /* desc, NAME, name */ USER_DLINK_DESC, USER_DLINK_NAME, USER_DLINK_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 36, VALUE_OPT_DBUG,
     /* equiv idx, value */ 36, VALUE_OPT_DBUG,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ DBUG_FLAGS, 0,
     /* last opt argumnt */ { DBUG_DFT_ARG },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptDbug,
     /* desc, NAME, name */ DBUG_DESC, DBUG_NAME, DBUG_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 37, VALUE_OPT_INFILE,
     /* equiv idx, value */ 37, VALUE_OPT_INFILE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 1, 1, 0,
     /* opt state flags  */ INFILE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --infile */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ INFILE_DESC, INFILE_NAME, INFILE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 38, VALUE_OPT_OUTFILE,
     /* equiv idx, value */ 38, VALUE_OPT_OUTFILE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 1, 1, 0,
     /* opt state flags  */ OUTFILE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --outfile */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ OUTFILE_DESC, OUTFILE_NAME, OUTFILE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 39, VALUE_OPT_CACHEFILE,
     /* equiv idx, value */ 39, VALUE_OPT_CACHEFILE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ CACHEFILE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --cachefile */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptCachefile,
     /* desc, NAME, name */ CACHEFILE_DESC, CACHEFILE_NAME, CACHEFILE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 40, VALUE_OPT_VERBOSE,
     /* equiv idx, value */ 40, VALUE_OPT_VERBOSE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ VERBOSE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --verbose */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ VERBOSE_DESC, VERBOSE_NAME, VERBOSE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 41, VALUE_OPT_DECODE,
     /* equiv idx, value */ 41, VALUE_OPT_DECODE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ DECODE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --decode */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aDecodeMustList, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ DECODE_DESC, DECODE_NAME, DECODE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 42, VALUE_OPT_FRAGROUTE,
     /* equiv idx, value */ 42, VALUE_OPT_FRAGROUTE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ FRAGROUTE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --fragroute */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ FRAGROUTE_DESC, FRAGROUTE_NAME, FRAGROUTE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 43, VALUE_OPT_FRAGDIR,
     /* equiv idx, value */ 43, VALUE_OPT_FRAGDIR,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ FRAGDIR_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --fragdir */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ aFragdirMustList, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ FRAGDIR_DESC, FRAGDIR_NAME, FRAGDIR_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 44, VALUE_OPT_SKIP_SOFT_ERRORS,
     /* equiv idx, value */ 44, VALUE_OPT_SKIP_SOFT_ERRORS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ SKIP_SOFT_ERRORS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --skip-soft-errors */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ SKIP_SOFT_ERRORS_DESC, SKIP_SOFT_ERRORS_NAME, SKIP_SOFT_ERRORS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 45, VALUE_OPT_VERSION,
     /* equiv idx, value */ 45, VALUE_OPT_VERSION,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ VERSION_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --version */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptVersion,
     /* desc, NAME, name */ VERSION_DESC, VERSION_NAME, VERSION_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 46, VALUE_OPT_LESS_HELP,
     /* equiv idx, value */ 46, VALUE_OPT_LESS_HELP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LESS_HELP_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --less-help */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptLess_Help,
     /* desc, NAME, name */ LESS_HELP_DESC, LESS_HELP_NAME, LESS_HELP_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ INDEX_OPT_HELP, VALUE_OPT_HELP,
     /* equiv idx value  */ NO_EQUIVALENT, VALUE_OPT_HELP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ OPTST_IMM | OPTST_NO_INIT, AOUSE_HELP,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doUsageOpt,
     /* desc, NAME, name */ HELP_DESC, NULL, HELP_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ INDEX_OPT_MORE_HELP, VALUE_OPT_MORE_HELP,
     /* equiv idx value  */ NO_EQUIVALENT, VALUE_OPT_MORE_HELP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ MORE_HELP_FLAGS, AOUSE_MORE_HELP,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL,  NULL,
     /* option proc      */ optionPagedUsage,
     /* desc, NAME, name */ MORE_HELP_DESC, NULL, MORE_HELP_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ INDEX_OPT_SAVE_OPTS, VALUE_OPT_SAVE_OPTS,
     /* equiv idx value  */ NO_EQUIVALENT, VALUE_OPT_SAVE_OPTS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ OPTST_SET_ARGTYPE(OPARG_TYPE_STRING)
                       | OPTST_ARG_OPTIONAL | OPTST_NO_INIT, AOUSE_SAVE_OPTS,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL,  NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ SAVE_OPTS_DESC, NULL, SAVE_OPTS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ INDEX_OPT_LOAD_OPTS, VALUE_OPT_LOAD_OPTS,
     /* equiv idx value  */ NO_EQUIVALENT, VALUE_OPT_LOAD_OPTS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, NOLIMIT, 0,
     /* opt state flags  */ OPTST_SET_ARGTYPE(OPARG_TYPE_STRING)
			  | OPTST_DISABLE_IMM, AOUSE_LOAD_OPTS,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ optionLoadOpt,
     /* desc, NAME, name */ LOAD_OPTS_DESC, LOAD_OPTS_NAME, LOAD_OPTS_name,
     /* disablement strs */ NO_LOAD_OPTS_name, LOAD_OPTS_pfx }
};

tOptDesc * const tcpedit_tcpedit_optDesc_p = optDesc + 0;

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/** Reference to the upper cased version of tcprewrite. */
#define zPROGNAME       (tcprewrite_opt_strs+3817)
/** Reference to the title line for tcprewrite usage. */
#define zUsageTitle     (tcprewrite_opt_strs+3828)
/** tcprewrite configuration file name. */
#define zRcName         (tcprewrite_opt_strs+3952)
/** Directories to search for tcprewrite config files. */
static char const * const apzHomeList[2] = {
    tcprewrite_opt_strs+3948,
    NULL };
/** The tcprewrite program bug email address. */
#define zBugsAddr       (tcprewrite_opt_strs+3966)
/** Clarification/explanation of what tcprewrite does. */
#define zExplain        (NULL)
/** Extra detail explaining what tcprewrite does. */
#define zDetail         (tcprewrite_opt_strs+4004)
/** The full version string for tcprewrite. */
#define zFullVersion    (NULL)
/* extracted from optcode.tlib near line 342 */

#if defined(ENABLE_NLS)
# define OPTPROC_BASE OPTPROC_TRANSLATE
  static tOptionXlateProc translate_option_strings;
#else
# define OPTPROC_BASE OPTPROC_NONE
# define translate_option_strings NULL
#endif /* ENABLE_NLS */

#define tcprewrite_full_usage (NULL)
#define tcprewrite_short_usage (NULL)

#endif /* not defined __doxygen__ */

/*
 *  Create the static procedure(s) declared above.
 */
/**
 * The callout function that invokes the optionUsage function.
 *
 * @param[in] opts the AutoOpts option description structure
 * @param[in] od   the descriptor for the "help" (usage) option.
 * @noreturn
 */
static void
doUsageOpt(tOptions * opts, tOptDesc * od)
{
    int ex_code;
    ex_code = TCPREWRITE_EXIT_SUCCESS;
    optionUsage(&tcprewriteOptions, ex_code);
    /* NOTREACHED */
    exit(TCPREWRITE_EXIT_FAILURE);
    (void)opts;
    (void)od;
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the tcp-sequence option.
 * Change all TCP sequence numbers, and related sequence-acknowledgement numbers.
 * They will be shifted by a random amount based on the provided seed.
 * @param[in] pOptions the tcprewrite options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptTcp_Sequence(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 1, LONG_MAX } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the mtu option.
 * Override the default 1500 byte MTU size for determining the maximum padding length
 * (--fixlen=pad) or when truncating (--mtu-trunc).
 * @param[in] pOptions the tcprewrite options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptMtu(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 1, MAX_SNAPLEN } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the tos option.
 * Allows you to override the TOS (also known as DiffServ/ECN) value in IPv4.
 * @param[in] pOptions the tcprewrite options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptTos(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, 255 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the tclass option.
 * Allows you to override the IPv6 Traffic Class field.
 * @param[in] pOptions the tcprewrite options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptTclass(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, 255 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the flowlabel option.
 * Allows you to override the 20bit IPv6 Flow Label field.  Has no effect on IPv4
 * packets.
 * @param[in] pOptions the tcprewrite options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptFlowlabel(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, 1048575 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the fuzz-seed option.
 * This fuzzing was designed as to test layer 7 protocols such as voip protocols.
 * It modifies randomly 1 out of X packets (where X = @var{--fuzz-factor}) in order
 * for stateful protocols to cover more of their code.  The random fuzzing actions
 * focus on data start and end because it often is the part of the data application
 * protocols base their decisions on.
 *
 * Possible fuzzing actions list:
 *  * drop packet
 *  * reduce packet size
 *  * edit packet Bytes:
 *    * Not all Bytes have the same probability of appearance in real life.
 *      Replace with 0x00, 0xFF, or a random byte with equal likelihood.
 *    * Not all Bytes have the same significance in a packet.
 *      Replace the start, the end, or the middle of the packet with equal likelihood.
 *  * do nothing (7 out of 8 packets)
 *
 * @param[in] pOptions the tcprewrite options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptFuzz_Seed(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, LONG_MAX } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the fuzz-factor option.
 * Sets the ratio of for @var{--fuzz-seed} option. By default this value is 8,
 * which means 1 in 8 packets are modified by fuzzing. Note that this ratio is
 * based on the random number generated by the supplied fuzz seed. Therefore by
 * default you cannot expect that exactly every eighth packet will be modified.
 * @param[in] pOptions the tcprewrite options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptFuzz_Factor(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 1, LONG_MAX } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the enet-mac-seed-keep-bytes option.
 * Keep some bytes untouched when usinging @var{--enet-mac-seed} option.
 * @param[in] pOptions the tcprewrite options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptEnet_Mac_Seed_Keep_Bytes(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 1, 6 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the enet-vlan-tag option.
 *
 * @param[in] pOptions the tcprewrite options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptEnet_Vlan_Tag(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, 4095 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the enet-vlan-cfi option.
 *
 * @param[in] pOptions the tcprewrite options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptEnet_Vlan_Cfi(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, 1 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the enet-vlan-pri option.
 *
 * @param[in] pOptions the tcprewrite options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptEnet_Vlan_Pri(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, 7 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the dbug option, when DEBUG is #define-d.
 * If configured with --enable-debug, then you can specify a verbosity
 * level for debugging output.  Higher numbers increase verbosity.
 * @param[in] pOptions the tcprewrite options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
#ifdef DEBUG
static void
doOptDbug(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0, 5 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}
#endif /* defined DEBUG */

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the cachefile option.
 * Use tcpprep cache file to split traffic based upon client/server relationships.
 * @param[in] pOptions the tcprewrite options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptCachefile(tOptions* pOptions, tOptDesc* pOptDesc)
{
    /*
     * Be sure the flag-code[0] handles special values for the options pointer
     * viz. (poptions <= OPTPROC_EMIT_LIMIT) *and also* the special flag bit
     * ((poptdesc->fOptState & OPTST_RESET) != 0) telling the option to
     * reset its state.
     */
    /* extracted from tcprewrite_opts.def, line 155 */

    options.cache_packets =
        read_cache(&options.cachedata, OPT_ARG(CACHEFILE), &options.comment);

    (void)pOptDesc;
    (void)pOptions;
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the version option.
 *
 * @param[in] pOptions the tcprewrite options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptVersion(tOptions* pOptions, tOptDesc* pOptDesc)
{
    /*
     * Be sure the flag-code[0] handles special values for the options pointer
     * viz. (poptions <= OPTPROC_EMIT_LIMIT) *and also* the special flag bit
     * ((poptdesc->fOptState & OPTST_RESET) != 0) telling the option to
     * reset its state.
     */
    /* extracted from tcprewrite_opts.def, line 246 */

    fprintf(stderr, "tcprewrite version: %s (build %s)", VERSION, git_version());
#ifdef DEBUG
    fprintf(stderr, " (debug)");
#endif
    fprintf(stderr, "\n");
    fprintf(stderr, "Copyright 2013-2022 by Fred Klassen <tcpreplay at appneta dot com> - AppNeta\n");
    fprintf(stderr, "Copyright 2000-2012 by Aaron Turner <aturner at synfin dot net>\n");
    fprintf(stderr, "The entire Tcpreplay Suite is licensed under the GPLv3\n");  
    fprintf(stderr, "Cache file supported: %s\n", CACHEVERSION);
#ifdef HAVE_LIBDNET
    fprintf(stderr, "Compiled against libdnet: %s\n", LIBDNET_VERSION);
#else
    fprintf(stderr, "Not compiled with libdnet.\n");
#endif
#ifdef HAVE_WINPCAP
    fprintf(stderr, "Compiled against winpcap: %s\n", get_pcap_version());
#elif defined HAVE_PF_RING_PCAP
    fprintf(stderr, "Compiled against PF_RING libpcap: %s\n", get_pcap_version());
#else
    fprintf(stderr, "Compiled against libpcap: %s\n", get_pcap_version());
#endif
#ifdef ENABLE_64BITS
    fprintf(stderr, "64 bit packet counters: enabled\n");
#else
    fprintf(stderr, "64 bit packet counters: disabled\n");
#endif
#ifdef ENABLE_VERBOSE
    fprintf(stderr, "Verbose printing via tcpdump: enabled\n");
#else
    fprintf(stderr, "Verbose printing via tcpdump: disabled\n");
#endif
#ifdef ENABLE_FRAGROUTE
    fprintf(stderr, "Fragroute engine: enabled\n");
#else
    fprintf(stderr, "Fragroute engine: disabled\n");
#endif
    exit(0);

    (void)pOptDesc;
    (void)pOptions;
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the less-help option.
 *
 * @param[in] pOptions the tcprewrite options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptLess_Help(tOptions* pOptions, tOptDesc* pOptDesc)
{
    /*
     * Be sure the flag-code[0] handles special values for the options pointer
     * viz. (poptions <= OPTPROC_EMIT_LIMIT) *and also* the special flag bit
     * ((poptdesc->fOptState & OPTST_RESET) != 0) telling the option to
     * reset its state.
     */
    /* extracted from tcprewrite_opts.def, line 295 */

    USAGE(EXIT_FAILURE);

    (void)pOptDesc;
    (void)pOptions;
}
/* extracted from optmain.tlib near line 1250 */

/**
 * The directory containing the data associated with tcprewrite.
 */
#ifndef  PKGDATADIR
# define PKGDATADIR ""
#endif

/**
 * Information about the person or institution that packaged tcprewrite
 * for the current distribution.
 */
#ifndef  WITH_PACKAGER
# define tcprewrite_packager_info NULL
#else
/** Packager information for tcprewrite. */
static char const tcprewrite_packager_info[] =
    "Packaged by " WITH_PACKAGER

# ifdef WITH_PACKAGER_VERSION
        " ("WITH_PACKAGER_VERSION")"
# endif

# ifdef WITH_PACKAGER_BUG_REPORTS
    "\nReport tcprewrite bugs to " WITH_PACKAGER_BUG_REPORTS
# endif
    "\n";
#endif
#ifndef __doxygen__

#endif /* __doxygen__ */
/**
 * The option definitions for tcprewrite.  The one structure that
 * binds them all.
 */
tOptions tcprewriteOptions = {
    OPTIONS_STRUCT_VERSION,
    0, NULL,                    /* original argc + argv    */
    ( OPTPROC_BASE
    + OPTPROC_ERRSTOP
    + OPTPROC_SHORTOPT
    + OPTPROC_LONGOPT
    + OPTPROC_NO_REQ_OPT
    + OPTPROC_NO_ARGS
    + OPTPROC_GNUUSAGE ),
    0, NULL,                    /* current option index, current option */
    NULL,         NULL,         zPROGNAME,
    zRcName,      zCopyright,   zLicenseDescrip,
    zFullVersion, apzHomeList,  zUsageTitle,
    zExplain,     zDetail,      optDesc,
    zBugsAddr,                  /* address to send bugs to */
    NULL, NULL,                 /* extensions/saved state  */
    optionUsage, /* usage procedure */
    translate_option_strings,   /* translation procedure */
    /*
     *  Indexes to special options
     */
    { INDEX_OPT_MORE_HELP, /* more-help option index */
      INDEX_OPT_SAVE_OPTS, /* save option index */
      NO_EQUIVALENT, /* '-#' option index */
      10 /* index of default opt */
    },
    51 /* full option count */, 47 /* user option count */,
    tcprewrite_full_usage, tcprewrite_short_usage,
    NULL, NULL,
    PKGDATADIR, tcprewrite_packager_info
};

#if ENABLE_NLS
/**
 * This code is designed to translate translatable option text for the
 * tcprewrite program.  These translations happen upon entry
 * to optionProcess().
 */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#ifdef HAVE_DCGETTEXT
# include <gettext.h>
#endif
#include <autoopts/usage-txt.h>

static char * AO_gettext(char const * pz);
static void   coerce_it(void ** s);

/**
 * AutoGen specific wrapper function for gettext.  It relies on the macro _()
 * to convert from English to the target language, then strdup-duplicates the
 * result string.  It tries the "libopts" domain first, then whatever has been
 * set via the \a textdomain(3) call.
 *
 * @param[in] pz the input text used as a lookup key.
 * @returns the translated text (if there is one),
 *   or the original text (if not).
 */
static char *
AO_gettext(char const * pz)
{
    char * res;
    if (pz == NULL)
        return NULL;
#ifdef HAVE_DCGETTEXT
    /*
     * While processing the option_xlateable_txt data, try to use the
     * "libopts" domain.  Once we switch to the option descriptor data,
     * do *not* use that domain.
     */
    if (option_xlateable_txt.field_ct != 0) {
        res = dgettext("libopts", pz);
        if (res == pz)
            res = (char *)VOIDP(_(pz));
    } else
        res = (char *)VOIDP(_(pz));
#else
    res = (char *)VOIDP(_(pz));
#endif
    if (res == pz)
        return res;
    res = strdup(res);
    if (res == NULL) {
        fputs(_("No memory for duping translated strings\n"), stderr);
        exit(TCPREWRITE_EXIT_FAILURE);
    }
    return res;
}

/**
 * All the pointers we use are marked "* const", but they are stored in
 * writable memory.  Coerce the mutability and set the pointer.
 */
static void coerce_it(void ** s) { *s = AO_gettext(*s);
}

/**
 * Translate all the translatable strings in the tcprewriteOptions
 * structure defined above.  This is done only once.
 */
static void
translate_option_strings(void)
{
    tOptions * const opts = &tcprewriteOptions;

    /*
     *  Guard against re-translation.  It won't work.  The strings will have
     *  been changed by the first pass through this code.  One shot only.
     */
    if (option_xlateable_txt.field_ct != 0) {
        /*
         *  Do the translations.  The first pointer follows the field count
         *  field.  The field count field is the size of a pointer.
         */
        char ** ppz = (char**)VOIDP(&(option_xlateable_txt));
        int     ix  = option_xlateable_txt.field_ct;

        do {
            ppz++; /* skip over field_ct */
            *ppz = AO_gettext(*ppz);
        } while (--ix > 0);
        /* prevent re-translation and disable "libopts" domain lookup */
        option_xlateable_txt.field_ct = 0;

        coerce_it(VOIDP(&(opts->pzCopyright)));
        coerce_it(VOIDP(&(opts->pzCopyNotice)));
        coerce_it(VOIDP(&(opts->pzFullVersion)));
        coerce_it(VOIDP(&(opts->pzUsageTitle)));
        coerce_it(VOIDP(&(opts->pzExplain)));
        coerce_it(VOIDP(&(opts->pzDetail)));
        {
            tOptDesc * od = opts->pOptDesc;
            for (ix = opts->optCt; ix > 0; ix--, od++)
                coerce_it(VOIDP(&(od->pzText)));
        }
    }
}
#endif /* ENABLE_NLS */

#ifdef DO_NOT_COMPILE_THIS_CODE_IT_IS_FOR_GETTEXT
/** I18N function strictly for xgettext.  Do not compile. */
static void bogus_function(void) {
  /* TRANSLATORS:

     The following dummy function was crated solely so that xgettext can
     extract the correct strings.  These strings are actually referenced
     by a field name in the tcprewriteOptions structure noted in the
     comments below.  The literal text is defined in tcprewrite_opt_strs.

     NOTE: the strings below are segmented with respect to the source string
     tcprewrite_opt_strs.  The strings above are handed off for translation
     at run time a paragraph at a time.  Consequently, they are presented here
     for translation a paragraph at a time.

     ALSO: often the description for an option will reference another option
     by name.  These are set off with apostrophe quotes (I hope).  Do not
     translate option names.
   */
  /* referenced via tcprewriteOptions.pzCopyright */
  puts(_("tcprewrite (tcprewrite)\n\
Copyright (C) 2000-2022 Aaron Turner and Fred Klassen, all rights reserved.\n\
This is free software. It is licensed for use, modification and\n\
redistribution under the terms of the GNU General Public License,\n\
version 3 or later <http://gnu.org/licenses/gpl.html>\n"));

  /* referenced via tcprewriteOptions.pzCopyNotice */
  puts(_("tcprewrite is free software: you can redistribute it and/or modify it under\n\
the terms of the GNU General Public License as published by the Free\n\
Software Foundation, either version 3 of the License, or (at your option)\n\
any later version.\n\n"));
  puts(_("tcprewrite is distributed in the hope that it will be useful, but WITHOUT\n\
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or\n\
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for\n\
more details.\n\n"));
  puts(_("You should have received a copy of the GNU General Public License along\n\
with this program.  If not, see <http://www.gnu.org/licenses/>.\n"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_(":"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Rewrite TCP/UDP ports"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Randomize src/dst IPv4/v6 addresses w/ given seed"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Rewrite IPv4/v6 addresses using pseudo-NAT"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Rewrite source IPv4/v6 addresses using pseudo-NAT"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Rewrite destination IPv4/v6 addresses using pseudo-NAT"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Rewrite IP addresses to be between two endpoints"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Change TCP Sequence (and ACK) numbers /w given seed"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Skip rewriting broadcast/multicast IPv4/v6 addresses"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Force recalculation of IPv4/TCP/UDP header checksums"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Override default MTU length (1500 bytes)"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Truncate packets larger then specified MTU"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Remove Ethernet checksums (FCS) from end of frames"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Modify the IPv4/v6 TTL/Hop Limit"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Set the IPv4 TOS/DiffServ/ECN byte"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Set the IPv6 Traffic Class byte"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Set the IPv6 Flow Label"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Pad or truncate packet data to match header length"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Fuzz 1 in X packets.  Edit bytes, length, or emulate packet drop"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Set the Fuzz 1 in X packet ratio (default 1 in 8 packets)"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Skip rewriting broadcast/multicast Layer 2 addresses"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Override output DLT encapsulation"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Override destination ethernet MAC addresses"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Override source ethernet MAC addresses"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Substitute MAC addresses"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Randomize MAC addresses"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Randomize MAC addresses"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Specify ethernet 802.1q VLAN tag mode"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Specify the new ethernet 802.1q VLAN tag value"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Specify the ethernet 802.1q VLAN CFI value"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Specify the ethernet 802.1q VLAN priority"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Specify VLAN tag protocol 802.1q or 802.1ad"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Specify HDLC control value"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Specify HDLC address"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Set output file DLT type"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Rewrite Data-Link layer with user specified data"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Enable debugging output"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Input pcap file to be processed"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Output pcap file"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Split traffic via tcpprep cache file"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Print decoded packets via tcpdump to STDOUT"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Arguments passed to tcpdump decoder"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Parse fragroute configuration file"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Which flows to apply fragroute to: c2s, s2c, both"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Skip writing packets with soft errors"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Print version information"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("Display less usage information and exit"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("display extended usage information and exit"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("extended usage information passed thru pager"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("save the option state to a config file"));

  /* referenced via tcprewriteOptions.pOptDesc->pzText */
  puts(_("load options from a config file"));

  /* referenced via tcprewriteOptions.pzUsageTitle */
  puts(_("tcprewrite (tcprewrite) - Rewrite the packets in a pcap file.\n\
Usage:  %s [ -<flag> [<val>] | --<name>[{=| }<val>] ]...\n"));

  /* referenced via tcprewriteOptions.pzDetail */
  puts(_("Tcprewrite is a tool to rewrite packets stored in 'pcap(3)' file format,\n\
such as created by tools such as 'tcpdump(1)' and 'wireshark(1)'.  Once a\n\
pcap file has had it's packets rewritten, they can be replayed back out on\n\
the network using 'tcpreplay(1)'.\n\n"));
  puts(_("tcprewrite currently supports reading the following DLT types:\n\n\n"));
  puts(_("'DLT_C_HDLC' aka Cisco HDLC\n\n\n\
'DLT_EN10MB' aka Ethernet\n\n\n"));
  puts(_("'DLT_LINUX_SLL' aka Linux Cooked Socket\n\n\n"));
  puts(_("'DLT_RAW' aka RAW IP\n\n\n\
'DLT_NULL' aka BSD Loopback\n\n\n"));
  puts(_("'DLT_LOOP' aka OpenBSD Loopback\n\n\n\
'DLT_IEEE802_11' aka 802.11a/b/g\n\n\n"));
  puts(_("'DLT_IEEE802_11_RADIO' aka 802.11a/b/g with Radiotap headers\n\n\n"));
  puts(_("'DLT_JUNIPER_ETHER' aka Juniper Encapsulated Ethernet\n\n\n"));
  puts(_("'DLT_PPP_SERIAL' aka PPP over Serial\n\n\
Please see the --dlt option for supported DLT types for writing.\n\n"));
  puts(_("The packet editing features of tcprewrite which distinguish between\n\
\"client\" and \"server\" traffic requires a tcpprep(1) cache file.\n\n\
For more details, please see the Tcpreplay Manual at:\n\
http://tcpreplay.appneta.com\n"));

  /* referenced via tcprewriteOptions.pzFullUsage */
  puts(_("<<<NOT-FOUND>>>"));

  /* referenced via tcprewriteOptions.pzShortUsage */
  puts(_("<<<NOT-FOUND>>>"));
  /* LIBOPTS-MESSAGES: */
#line 67 "../autoopts.c"
  puts(_("allocation of %d bytes failed\n"));
#line 89 "../autoopts.c"
  puts(_("allocation of %d bytes failed\n"));
#line 48 "../init.c"
  puts(_("AutoOpts function called without option descriptor\n"));
#line 81 "../init.c"
  puts(_("\tThis exceeds the compiled library version:  "));
#line 79 "../init.c"
  puts(_("Automated Options Processing Error!\n"
       "\t%s called AutoOpts function with structure version %d:%d:%d.\n"));
#line 78 "../autoopts.c"
  puts(_("realloc of %d bytes at 0x%p failed\n"));
#line 83 "../init.c"
  puts(_("\tThis is less than the minimum library version:  "));
#line 121 "../version.c"
  puts(_("Automated Options version %s\n"
       "\tCopyright (C) 1999-2017 by Bruce Korb - all rights reserved\n"));
#line 49 "../makeshell.c"
  puts(_("(AutoOpts bug):  %s.\n"));
#line 90 "../reset.c"
  puts(_("optionResetOpt() called, but reset-option not configured"));
#line 241 "../usage.c"
  puts(_("could not locate the 'help' option"));
#line 330 "../autoopts.c"
  puts(_("optionProcess() was called with invalid data"));
#line 697 "../usage.c"
  puts(_("invalid argument type specified"));
#line 568 "../find.c"
  puts(_("defaulted to option with optional arg"));
#line 76 "../alias.c"
  puts(_("aliasing option is out of range."));
#line 210 "../enum.c"
  puts(_("%s error:  the keyword '%s' is ambiguous for %s\n"));
#line 78 "../find.c"
  puts(_("  The following options match:\n"));
#line 263 "../find.c"
  puts(_("%s: ambiguous option name: %s (matches %d options)\n"));
#line 161 "../check.c"
  puts(_("%s: Command line arguments required\n"));
#line 43 "../alias.c"
  puts(_("%d %s%s options allowed\n"));
#line 56 "../makeshell.c"
  puts(_("%s error %d (%s) calling %s for '%s'\n"));
#line 268 "../makeshell.c"
  puts(_("interprocess pipe"));
#line 171 "../version.c"
  puts(_("error: version option argument '%c' invalid.  Use:\n"
       "\t'v' - version only\n"
       "\t'c' - version and copyright\n"
       "\t'n' - version and full copyright notice\n"));
#line 58 "../check.c"
  puts(_("%s error:  the '%s' and '%s' options conflict\n"));
#line 187 "../find.c"
  puts(_("%s: The '%s' option has been disabled."));
#line 400 "../find.c"
  puts(_("%s: The '%s' option has been disabled."));
#line 38 "../alias.c"
  puts(_("-equivalence"));
#line 439 "../find.c"
  puts(_("%s: illegal option -- %c\n"));
#line 110 "../reset.c"
  puts(_("%s: illegal option -- %c\n"));
#line 241 "../find.c"
  puts(_("%s: illegal option -- %s\n"));
#line 740 "../find.c"
  puts(_("%s: illegal option -- %s\n"));
#line 118 "../reset.c"
  puts(_("%s: illegal option -- %s\n"));
#line 305 "../find.c"
  puts(_("%s: unknown vendor extension option -- %s\n"));
#line 135 "../enum.c"
  puts(_("  or an integer from %d through %d\n"));
#line 145 "../enum.c"
  puts(_("  or an integer from %d through %d\n"));
#line 696 "../usage.c"
  puts(_("%s error:  invalid option descriptor for %s\n"));
#line 1030 "../usage.c"
  puts(_("%s error:  invalid option descriptor for %s\n"));
#line 355 "../find.c"
  puts(_("%s: invalid option name: %s\n"));
#line 497 "../find.c"
  puts(_("%s: The '%s' option requires an argument.\n"));
#line 150 "../autoopts.c"
  puts(_("(AutoOpts bug):  Equivalenced option '%s' was equivalenced to both\n"
       "\t'%s' and '%s'."));
#line 94 "../check.c"
  puts(_("%s error:  The %s option is required\n"));
#line 602 "../find.c"
  puts(_("%s: The '%s' option cannot have an argument.\n"));
#line 151 "../check.c"
  puts(_("%s: Command line arguments are not allowed.\n"));
#line 568 "../save.c"
  puts(_("error %d (%s) creating %s\n"));
#line 210 "../enum.c"
  puts(_("%s error:  '%s' does not match any %s keywords.\n"));
#line 93 "../reset.c"
  puts(_("%s error: The '%s' option requires an argument.\n"));
#line 122 "../save.c"
  puts(_("error %d (%s) stat-ing %s\n"));
#line 175 "../save.c"
  puts(_("error %d (%s) stat-ing %s\n"));
#line 143 "../restore.c"
  puts(_("%s error: no saved option state\n"));
#line 225 "../autoopts.c"
  puts(_("'%s' is not a command line option.\n"));
#line 113 "../time.c"
  puts(_("%s error:  '%s' is not a recognizable date/time.\n"));
#line 50 "../time.c"
  puts(_("%s error:  '%s' is not a recognizable time duration.\n"));
#line 92 "../check.c"
  puts(_("%s error:  The %s option must appear %d times.\n"));
#line 165 "../numeric.c"
  puts(_("%s error:  '%s' is not a recognizable number.\n"));
#line 176 "../enum.c"
  puts(_("%s error:  %s exceeds %s keyword count\n"));
#line 279 "../usage.c"
  puts(_("Try '%s %s' for more information.\n"));
#line 45 "../alias.c"
  puts(_("one %s%s option allowed\n"));
#line 170 "../makeshell.c"
  puts(_("standard output"));
#line 905 "../makeshell.c"
  puts(_("standard output"));
#line 223 "../usage.c"
  puts(_("standard output"));
#line 364 "../usage.c"
  puts(_("standard output"));
#line 574 "../usage.c"
  puts(_("standard output"));
#line 178 "../version.c"
  puts(_("standard output"));
#line 223 "../usage.c"
  puts(_("standard error"));
#line 364 "../usage.c"
  puts(_("standard error"));
#line 574 "../usage.c"
  puts(_("standard error"));
#line 178 "../version.c"
  puts(_("standard error"));
#line 170 "../makeshell.c"
  puts(_("write"));
#line 905 "../makeshell.c"
  puts(_("write"));
#line 222 "../usage.c"
  puts(_("write"));
#line 363 "../usage.c"
  puts(_("write"));
#line 573 "../usage.c"
  puts(_("write"));
#line 177 "../version.c"
  puts(_("write"));
#line 60 "../numeric.c"
  puts(_("%s error:  %s option value %ld is out of range.\n"));
#line 44 "../check.c"
  puts(_("%s error:  %s option requires the %s option\n"));
#line 121 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
#line 174 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
#line 193 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
#line 567 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
  /* END-LIBOPTS-MESSAGES */

  /* USAGE-TEXT: */
#line 822 "../usage.c"
  puts(_("\t\t\t\t- an alternate for '%s'\n"));
#line 1097 "../usage.c"
  puts(_("Version, usage and configuration options:"));
#line 873 "../usage.c"
  puts(_("\t\t\t\t- default option for unnamed options\n"));
#line 786 "../usage.c"
  puts(_("\t\t\t\t- disabled as '--%s'\n"));
#line 1066 "../usage.c"
  puts(_(" --- %-14s %s\n"));
#line 1064 "../usage.c"
  puts(_("This option has been disabled"));
#line 813 "../usage.c"
  puts(_("\t\t\t\t- enabled by default\n"));
#line 40 "../alias.c"
  puts(_("%s error:  only "));
#line 1143 "../usage.c"
  puts(_(" - examining environment variables named %s_*\n"));
#line 168 "../file.c"
  puts(_("\t\t\t\t- file must not pre-exist\n"));
#line 172 "../file.c"
  puts(_("\t\t\t\t- file must pre-exist\n"));
#line 329 "../usage.c"
  puts(_("Options are specified by doubled hyphens and their name or by a single\n"
       "hyphen and the flag character.\n"));
#line 882 "../makeshell.c"
  puts(_("\n"
       "= = = = = = = =\n\n"
       "This incarnation of genshell will produce\n"
       "a shell script to parse the options for %s:\n\n"));
#line 142 "../enum.c"
  puts(_("  or an integer mask with any of the lower %d bits set\n"));
#line 846 "../usage.c"
  puts(_("\t\t\t\t- is a set membership option\n"));
#line 867 "../usage.c"
  puts(_("\t\t\t\t- must appear between %d and %d times\n"));
#line 331 "../usage.c"
  puts(_("Options are specified by single or double hyphens and their name.\n"));
#line 853 "../usage.c"
  puts(_("\t\t\t\t- may appear multiple times\n"));
#line 840 "../usage.c"
  puts(_("\t\t\t\t- may not be preset\n"));
#line 1258 "../usage.c"
  puts(_("   Arg Option-Name    Description\n"));
#line 1194 "../usage.c"
  puts(_("  Flg Arg Option-Name    Description\n"));
#line 1252 "../usage.c"
  puts(_("  Flg Arg Option-Name    Description\n"));
#line 1253 "../usage.c"
  puts(_(" %3s %s"));
#line 1259 "../usage.c"
  puts(_(" %3s %s"));
#line 336 "../usage.c"
  puts(_("The '-#<number>' option may omit the hash char\n"));
#line 332 "../usage.c"
  puts(_("All arguments are named options.\n"));
#line 920 "../usage.c"
  puts(_(" - reading file %s"));
#line 358 "../usage.c"
  puts(_("\n"
       "Please send bug reports to:  <%s>\n"));
#line 100 "../version.c"
  puts(_("\n"
       "Please send bug reports to:  <%s>\n"));
#line 129 "../version.c"
  puts(_("\n"
       "Please send bug reports to:  <%s>\n"));
#line 852 "../usage.c"
  puts(_("\t\t\t\t- may NOT appear - preset only\n"));
#line 893 "../usage.c"
  puts(_("\n"
       "The following option preset mechanisms are supported:\n"));
#line 1141 "../usage.c"
  puts(_("\n"
       "The following option preset mechanisms are supported:\n"));
#line 631 "../usage.c"
  puts(_("prohibits these options:\n"));
#line 626 "../usage.c"
  puts(_("prohibits the option '%s'\n"));
#line 81 "../numeric.c"
  puts(_("%s%ld to %ld"));
#line 79 "../numeric.c"
  puts(_("%sgreater than or equal to %ld"));
#line 75 "../numeric.c"
  puts(_("%s%ld exactly"));
#line 68 "../numeric.c"
  puts(_("%sit must lie in one of the ranges:\n"));
#line 68 "../numeric.c"
  puts(_("%sit must be in the range:\n"));
#line 88 "../numeric.c"
  puts(_(", or\n"));
#line 66 "../numeric.c"
  puts(_("%sis scalable with a suffix: k/K/m/M/g/G/t/T\n"));
#line 77 "../numeric.c"
  puts(_("%sless than or equal to %ld"));
#line 339 "../usage.c"
  puts(_("Operands and options may be intermixed.  They will be reordered.\n"));
#line 601 "../usage.c"
  puts(_("requires the option '%s'\n"));
#line 604 "../usage.c"
  puts(_("requires these options:\n"));
#line 1270 "../usage.c"
  puts(_("   Arg Option-Name   Req?  Description\n"));
#line 1264 "../usage.c"
  puts(_("  Flg Arg Option-Name   Req?  Description\n"));
#line 143 "../enum.c"
  puts(_("or you may use a numeric representation.  Preceding these with a '!'\n"
       "will clear the bits, specifying 'none' will clear all bits, and 'all'\n"
       "will set them all.  Multiple entries may be passed as an option\n"
       "argument list.\n"));
#line 859 "../usage.c"
  puts(_("\t\t\t\t- may appear up to %d times\n"));
#line 52 "../enum.c"
  puts(_("The valid \"%s\" option keywords are:\n"));
#line 1101 "../usage.c"
  puts(_("The next option supports vendor supported extra options:"));
#line 722 "../usage.c"
  puts(_("These additional options are:"));
  /* END-USAGE-TEXT */
}
#endif /* uncompilable code */
#ifdef  __cplusplus
}
#endif
/* tcprewrite_opts.c ends here */
